# Generated by Django 2.1.5 on 2019-01-30 17:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0002_auto_20190130_1634'),
    ]

    operations = [
        migrations.CreateModel(
            name='Statistic',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('kamailio_id', models.PositiveSmallIntegerField()),
                ('time_stamp', models.IntegerField(default=0)),
                ('random', models.IntegerField(default=0)),
                ('shm_used_size', models.IntegerField(default=0)),
                ('shm_real_used_size', models.IntegerField(default=0)),
                ('shm_max_used_size', models.IntegerField(default=0)),
                ('shm_free_used_size', models.IntegerField(default=0)),
                ('ul_users', models.IntegerField(default=0)),
                ('ul_contacts', models.IntegerField(default=0)),
            ],
            options={
                'db_table': 'statistics',
                'ordering': ('-pk',),
            },
        ),
        migrations.AlterField(
            model_name='acccdr',
            name='end_time',
            field=models.DateTimeField(help_text='End date and time'),
        ),
        migrations.AlterField(
            model_name='acccdr',
            name='start_time',
            field=models.DateTimeField(db_index=True, help_text='Start date and time'),
        ),
        migrations.AlterField(
            model_name='location',
            name='expires',
            field=models.DateTimeField(db_index=True, help_text='Date and time when this entry expires.'),
        ),
        migrations.AlterField(
            model_name='location',
            name='last_modified',
            field=models.DateTimeField(help_text='Date and time when this entry was last modified'),
        ),
        migrations.AlterField(
            model_name='locationattrs',
            name='last_modified',
            field=models.DateTimeField(db_index=True, help_text='Date and time when this entry was last modified'),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='disabled',
            field=models.IntegerField(choices=[(0, 'disabled'), (1, 'enabled')], default=0, help_text='RTPEngine instance state on startup'),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='stamp',
            field=models.DateTimeField(auto_now_add=True, help_text='RTPEngine instance add timestamp'),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='url',
            field=models.CharField(help_text='RTPEngine instance socket URL. Example : udp:rtpengine1.domain:8800', max_length=64),
        ),
        migrations.AlterField(
            model_name='rtpengine',
            name='weight',
            field=models.IntegerField(default=1, help_text='RTPEngine instance weight on startup'),
        ),
    ]



# Generated by Django 2.1.5 on 2020-05-14 17:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0012_auto_20200514_1705'),
    ]

    operations = [
        migrations.AddField(
            model_name='missedcall',
            name='call_direction',
            field=models.CharField(default='', help_text='inbound / outbound', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='called_destination',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='called_did',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='caller_destination',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='did_destination',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='e164_called',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='e164_caller',
            field=models.CharField(default='', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='leg_a_class',
            field=models.CharField(default='', help_text='on-net / off-net', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='leg_b_class',
            field=models.CharField(default='', help_text='on-net / off-net', max_length=128),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_c_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_c_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_p_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='o_p_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='orig_customer',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='orig_provider',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_c_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_c_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_p_rate_id',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='t_p_rate_type',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='term_customer',
            field=models.IntegerField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='missedcall',
            name='term_provider',
            field=models.IntegerField(blank=True, null=True),
        ),
    ]



# Generated by Django 2.1.4 on 2018-12-03 17:32

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Acc',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('method', models.CharField(default='', help_text='A method is the primary function that a request is meant to invoke on a server.', max_length=16)),
                ('from_tag', models.CharField(default='', help_text='The tag parameter serves as a general mechanism to identify a dialog, which is the combination of the Call-ID along with two tags, one from participant in the dialog.', max_length=64)),
                ('to_tag', models.CharField(default='', help_text='The tag parameter serves as a general mechanism to identify a dialog, which is the combination of the Call-ID along with two tags, one from participant in the dialog.', max_length=64)),
                ('callid', models.CharField(db_index=True, default='', help_text='Call-ID header field uniquely identifies a particular invitation or all registrations of a particular client.', max_length=255)),
                ('sip_code', models.CharField(default='', help_text='SIP reply code.', max_length=3)),
                ('sip_reason', models.CharField(default='', help_text='SIP reply reason', max_length=128)),
                ('time', models.DateTimeField(help_text='Date and time when this record was written.')),
                ('time_attr', models.IntegerField(help_text='Unix timestamp')),
                ('time_exten', models.IntegerField(help_text='extended value related to the time of event')),
            ],
            options={
                'db_table': 'acc',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='AccCdr',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('start_time', models.DateTimeField(db_index=True, default='2000-01-01 00:00:00', help_text='Start date and time')),
                ('end_time', models.DateTimeField(default='2000-01-01 00:00:00', help_text='End date and time')),
                ('duration', models.DecimalField(decimal_places=3, default=0, help_text='Duration', max_digits=10)),
            ],
            options={
                'db_table': 'acc_cdrs',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='Dialog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('hash_entry', models.IntegerField(help_text='Number of the hash entry in the dialog hash table')),
                ('hash_id', models.IntegerField(help_text='The ID on the hash entry')),
                ('callid', models.CharField(help_text='Call-ID of the dialog', max_length=255)),
                ('from_uri', models.CharField(help_text='The URI of the FROM header (as per INVITE)', max_length=128)),
                ('from_tag', models.CharField(help_text='The tag parameter serves as a general mechanism to identify a dialog, which is the combination of the Call-ID along with two tags, one from participant in the dialog.', max_length=64)),
                ('to_uri', models.CharField(help_text='The URI of the TO header (as per INVITE)', max_length=128)),
                ('to_tag', models.CharField(help_text='The tag parameter serves as a general mechanism to identify a dialog, which is the combination of the Call-ID along with two tags, one from participant in the dialog.', max_length=64)),
                ('caller_cseq', models.CharField(help_text='Last Cseq number on the caller side.', max_length=20)),
                ('callee_cseq', models.CharField(help_text='Last Cseq number on the callee side.', max_length=20)),
                ('caller_route_set', models.CharField(blank=True, help_text='Route set on the caller side.', max_length=512, null=True)),
                ('callee_route_set', models.CharField(blank=True, help_text='Route set on the callee side.', max_length=512, null=True)),
                ('caller_contact', models.CharField(help_text="Caller's contact uri.", max_length=128)),
                ('callee_contact', models.CharField(help_text="Callee's contact uri.", max_length=128)),
                ('caller_sock', models.CharField(help_text='Local socket used to communicate with caller', max_length=64)),
                ('callee_stock', models.CharField(help_text='Local socket used to communicate with callee', max_length=64)),
                ('state', models.IntegerField(help_text='The state of the dialog.')),
                ('start_time', models.IntegerField(help_text='The timestamp (unix time) when the dialog was confirmed.')),
                ('timeout', models.IntegerField(help_text='The timestamp (unix time) when the dialog will expire.')),
                ('sflags', models.IntegerField(help_text='The flags to set for dialog and accesible from config file.')),
                ('iflags', models.IntegerField(help_text='The internal flags for dialog.')),
                ('toroute_name', models.CharField(blank=True, help_text='The name of route to be executed at dialog timeout.', max_length=32, null=True)),
                ('req_uri', models.CharField(help_text='The URI of initial request in dialog', max_length=128)),
                ('xdata', models.CharField(blank=True, help_text='Extra data associated to the dialog (e.g., serialized profiles).', max_length=512, null=True)),
            ],
            options={
                'verbose_name_plural': 'SIP dialogs',
                'db_table': 'dialog',
                'ordering': ('-pk',),
                'verbose_name': 'SIP dialog',
            },
        ),
        migrations.CreateModel(
            name='DialogVar',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('hash_entry', models.IntegerField(help_text='Number of the hash entry in the dialog hash table')),
                ('hash_id', models.IntegerField(help_text='The ID on the hash entry')),
                ('dialog_key', models.CharField(help_text='The key of the dialog variable', max_length=128)),
                ('dialog_value', models.CharField(help_text='The value of the dialog variable', max_length=512)),
            ],
            options={
                'verbose_name_plural': 'SIP dialog vars',
                'db_table': 'dialog_vars',
                'ordering': ('-pk',),
                'verbose_name': 'SIP dialog vars',
            },
        ),
        migrations.CreateModel(
            name='GlobalBlackList',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('prefix', models.CharField(db_index=True, default='', help_text='The prefix that is matched for the blacklist', max_length=64)),
                ('whitelist', models.CharField(choices=[('0', 'blacklist'), ('1', 'whitelist')], default='0', help_text='Specify if this a blacklist (0) or a whitelist (1) entry', max_length=1)),
                ('description', models.TextField(default='', help_text='A comment for the entry', max_length=255)),
            ],
            options={
                'db_table': 'globalblacklist',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='Htable',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('key_name', models.CharField(default='', help_text='Name of the hash key', max_length=64)),
                ('key_type', models.IntegerField(default=0, help_text='Type of the key')),
                ('value_type', models.IntegerField(default=0, help_text='Type of the value')),
                ('key_value', models.CharField(default='', help_text='The value of the key', max_length=128)),
                ('expires', models.IntegerField(default=0, help_text='The epoch at which the key expires')),
            ],
            options={
                'db_table': 'htable',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='Location',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ruid', models.CharField(default='', help_text='Record internal unique id', max_length=64, unique=True)),
                ('username', models.CharField(default='', help_text='Username / phone number', max_length=64)),
                ('domain', models.CharField(blank=True, help_text='Doamin name', max_length=64, null=True)),
                ('contact', models.CharField(default='', help_text='Contact header field value provides a URI whoses meaning depends on the type of request or response it is in.', max_length=512)),
                ('received', models.CharField(blank=True, help_text='Received IP:PORT in the format SIP:IP:PORT', max_length=128, null=True)),
                ('path', models.CharField(blank=True, help_text='Path Header(s) per RFC 3327', max_length=512, null=True)),
                ('expires', models.DateTimeField(db_index=True, default='2030-05-28 21:32:15', help_text='Date and time when this entry expires.')),
                ('q', models.DecimalField(decimal_places=2, default=1.0, help_text='Value used for preferential routing.', max_digits=10)),
                ('callid', models.CharField(default='Default-Call-ID', help_text='\t Call-ID header field uniquely identifies a particular invitation or all registrations of a particular client.', max_length=255)),
                ('cseq', models.IntegerField(default=1, help_text='CSeq header field contains a single decimal sequence number and the request method.')),
                ('last_modified', models.DateTimeField(default='2000-01-01 00:00:01', help_text='Date and time when this entry was last modified')),
                ('flags', models.IntegerField(default=0, help_text='Internal flags')),
                ('cflags', models.IntegerField(default=0, help_text='Branch and contact flags')),
                ('user_agent', models.CharField(default='', help_text='User-Agent header field contains information about the UAC originating the request.', max_length=255)),
                ('socket', models.CharField(blank=True, help_text='Socket used to connect to Kamailio. For example: UDP:IP:PORT', max_length=64, null=True)),
                ('methods', models.IntegerField(blank=True, help_text='Flags that indicate the SIP Methods this contact will accept.', null=True)),
                ('instance', models.CharField(blank=True, help_text='The value of SIP instance parameter for GRUU.', max_length=255, null=True)),
                ('reg_id', models.IntegerField(default=0, help_text='The value of reg-id contact parameter')),
                ('server_id', models.IntegerField(default=0, help_text='The value of server_id from configuration file')),
                ('connection_id', models.IntegerField(default=0, help_text='The value of connection id for location record')),
                ('keepalive', models.IntegerField(default=0, help_text='The value to control sending keep alive requests')),
                ('partition', models.IntegerField(default=0, help_text='The value to of the partition for keep alive requests')),
            ],
            options={
                'db_table': 'location',
                'ordering': ('-pk',),
                'verbose_name': 'user location',
            },
        ),
        migrations.CreateModel(
            name='LocationAttrs',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('ruid', models.CharField(default='', help_text='Record internal unique id', max_length=64)),
                ('username', models.CharField(default='', help_text='Username / phone number', max_length=64)),
                ('domain', models.CharField(blank=True, help_text='Domain name', max_length=64, null=True)),
                ('aname', models.CharField(default='', help_text='Attribute name', max_length=64)),
                ('atype', models.IntegerField(default=0, help_text='Attribute type')),
                ('avalue', models.CharField(default='', help_text='Attribute value', max_length=512)),
                ('last_modified', models.DateTimeField(db_index=True, default='2000-01-01 00:00:01', help_text='Date and time when this entry was last modified')),
            ],
            options={
                'db_table': 'location_attrs',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='MissedCall',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('method', models.CharField(default='', help_text='A method is the primary function that a request is meant to invoke on a server.', max_length=16)),
                ('from_tag', models.CharField(default='', help_text='The tag parameter serves as a general mechanism to identify a dialog, which is the combination of the Call-ID along with two tags, one from participant in the dialog.', max_length=64)),
                ('to_tag', models.CharField(default='', help_text='The tag parameter serves as a general mechanism to identify a dialog, which is the combination of the Call-ID along with two tags, one from participant in the dialog.', max_length=64)),
                ('callid', models.CharField(db_index=True, default='', help_text='Call-ID header field uniquely identifies a particular invitation or all registrations of a particular client.', max_length=255)),
                ('sip_code', models.CharField(default='', help_text='SIP reply code.', max_length=3)),
                ('sip_reason', models.CharField(default='', help_text='SIP reply reason', max_length=128)),
                ('time', models.DateTimeField(help_text='Date and time when this record was written.')),
            ],
            options={
                'db_table': 'missed_calls',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='Mtree',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tprefix', models.CharField(default='', help_text='Key to be used to index the values in the tree, usually a DID or prefix', max_length=32, unique=True)),
                ('tvalue', models.CharField(default='', help_text='The value of the key', max_length=128)),
            ],
            options={
                'db_table': 'mtree',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='Mtrees',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('tname', models.CharField(default='', help_text='Name of shared memory tree', max_length=128)),
                ('tprefix', models.CharField(default='', help_text='Key to be used to index the values in the tree, usually a DID or prefix', max_length=32)),
                ('tvalue', models.CharField(default='', help_text='The value of the key', max_length=128)),
            ],
            options={
                'db_table': 'mtrees',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='PipeLimit',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('pipeid', models.CharField(default='', help_text='Unique ID for pipe', max_length=64)),
                ('algorithm', models.CharField(choices=[('NOP', 'NOP'), ('RED', 'RED'), ('TAILDROP', 'TAILDROP'), ('FEEDBACK', 'FEEDBACK'), ('NETWORK', 'NETWORK')], default='TAILDROP', help_text='Algorithm to be used for pipe limits. See the readme of the module for description of available options: NOP, RED, TAILDROP, FEEDBACK, NETWORK', max_length=32)),
                ('plimit', models.IntegerField(default=0, help_text='Pipe limit (hits per second)')),
            ],
            options={
                'db_table': 'pl_pipes',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='RtpEngine',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('setid', models.IntegerField(default='0', help_text='RTPEngine instance socket ID')),
                ('url', models.CharField(help_text='RTPEngine instance socket URL', max_length=64)),
                ('weight', models.IntegerField(default=1, help_text='RTPEngine instance weight')),
                ('disabled', models.IntegerField(default=0, help_text='RTPEngine instance state')),
                ('stamp', models.DateTimeField(default='1900-01-01 00:00:01', help_text='RTPEngine instance add timestamp')),
            ],
            options={
                'db_table': 'rtpengine',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='SpeedDial',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('username', models.CharField(default='', help_text='Username / phone number', max_length=64)),
                ('domain', models.CharField(default='', help_text='Domain name', max_length=64)),
                ('sd_username', models.CharField(default='', help_text='Speed dial username', max_length=64)),
                ('sd_domain', models.CharField(default='', help_text='Speed dial domain', max_length=64)),
                ('new_uri', models.CharField(default='', help_text='New URI', max_length=128)),
                ('fname', models.CharField(default='', help_text='First name', max_length=64)),
                ('lname', models.CharField(default='', help_text='Last name', max_length=64)),
                ('description', models.CharField(default='', help_text='Description', max_length=64)),
            ],
            options={
                'db_table': 'speed_dial',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='Trusted',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('src_ip', models.CharField(db_index=True, default='', help_text='Source address is equal to source address of request', max_length=50)),
                ('proto', models.CharField(choices=[('any', 'any'), ('udp', 'udp'), ('tcp', 'tcp'), ('tls', 'tls'), ('sctp', 'sctp')], default='any', help_text='Transport protocol is either any or equal to transport protocol of request', max_length=4)),
                ('from_pattern', models.CharField(blank=True, help_text='Regular expression matches From URI of request.', max_length=64, null=True)),
                ('ruri_pattern', models.CharField(blank=True, help_text='Regular expression matches Request URI of request.', max_length=64, null=True)),
                ('tag', models.CharField(default='', help_text='Tag', max_length=64)),
                ('priority', models.IntegerField(default=0, help_text='Priority of rule')),
            ],
            options={
                'db_table': 'trusted',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='UacReg',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('l_uuid', models.CharField(db_index=True, default='', help_text='Local unique id used to build and match contact addresses.', max_length=64)),
                ('l_username', models.CharField(default='', help_text='Local username', max_length=64)),
                ('l_domain', models.CharField(default='', help_text='Local domain', max_length=64)),
                ('r_username', models.CharField(default='', help_text='Remote username', max_length=64)),
                ('r_domain', models.CharField(default='', help_text='Remote domain', max_length=64)),
                ('realm', models.CharField(default='', help_text='realm', max_length=64)),
                ('auth_username', models.CharField(default='', help_text='Auth username', max_length=64)),
                ('auth_password', models.CharField(default='', help_text='Auth password', max_length=64)),
                ('auth_ha1', models.CharField(default='', help_text='Hashed (HA1) auth password', max_length=128)),
                ('auth_proxy', models.CharField(default='', help_text='Outbound proxy SIP address', max_length=128)),
                ('expires', models.IntegerField(default=0, help_text='Expiration time in seconds, 0 means disabled')),
                ('flags', models.IntegerField(default=0, help_text='Flags to control the behaviour')),
                ('reg_delay', models.IntegerField(default=0, help_text='initial registration delay')),
            ],
            options={
                'db_table': 'uacreg',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='UserBlackList',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('username', models.CharField(default='', help_text='The user that is used for the blacklist lookup', max_length=64)),
                ('domain', models.CharField(default='', help_text='The domain that is used for the blacklist lookup', max_length=64)),
                ('prefix', models.CharField(default='', help_text='The prefix that is matched for the blacklist', max_length=64)),
                ('whitelist', models.CharField(choices=[('0', 'blacklist'), ('1', 'whitelist')], default='0', help_text='Specify if this a blacklist (0) or a whitelist (1) entry', max_length=1)),
            ],
            options={
                'db_table': 'userblacklist',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='Version',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('table_name', models.CharField(max_length=32, unique=True)),
                ('table_version', models.IntegerField(default=0)),
            ],
            options={
                'db_table': 'version',
                'ordering': ('-pk',),
            },
        ),
        migrations.AddIndex(
            model_name='userblacklist',
            index=models.Index(fields=['username', 'domain', 'prefix'], name='userblackli_usernam_90d9fe_idx'),
        ),
        migrations.AlterUniqueTogether(
            name='speeddial',
            unique_together={('username', 'domain', 'sd_domain', 'sd_username')},
        ),
        migrations.AlterUniqueTogether(
            name='rtpengine',
            unique_together={('setid', 'url')},
        ),
        migrations.AlterUniqueTogether(
            name='mtrees',
            unique_together={('tname', 'tprefix', 'tvalue')},
        ),
        migrations.AddIndex(
            model_name='locationattrs',
            index=models.Index(fields=['username', 'domain', 'ruid'], name='location_at_usernam_1d74be_idx'),
        ),
        migrations.AddIndex(
            model_name='location',
            index=models.Index(fields=['username', 'domain', 'contact'], name='location_usernam_61c9cb_idx'),
        ),
        migrations.AddIndex(
            model_name='location',
            index=models.Index(fields=['server_id', 'connection_id'], name='location_server__3d62be_idx'),
        ),
        migrations.AddIndex(
            model_name='dialogvar',
            index=models.Index(fields=['hash_entry', 'hash_id'], name='dialog_vars_hash_en_c42e1f_idx'),
        ),
        migrations.AddIndex(
            model_name='dialog',
            index=models.Index(fields=['hash_entry', 'hash_id'], name='dialog_hash_en_c7de57_idx'),
        ),
    ]



# Generated by Django 2.1.5 on 2020-05-14 15:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0010_auto_20200321_1551'),
    ]

    operations = [
        migrations.AlterField(
            model_name='dialogvar',
            name='dialog_value',
            field=models.TextField(help_text='The value of the dialog variable'),
        ),
    ]



# -*- coding: utf-8 -*-
from django.contrib import admin
from django import forms
from .models import Domain, Dialog, DialogVar, Acc, AccCdr, MissedCall, UacReg, Trusted, Version, Location, LocationAttrs, UserBlackList, GlobalBlackList, SpeedDial, PipeLimit, Mtree, Mtrees, Htable, RtpEngine, Statistic


class DomainAdminForm(forms.ModelForm):

    class Meta:
        model = Domain
        fields = '__all__'


class DomainAdmin(admin.ModelAdmin):
    form = DomainAdminForm
    list_display = ['domain', 'did', 'last_modified']


admin.site.register(Domain, DomainAdmin)


class DialogAdminForm(forms.ModelForm):

    class Meta:
        model = Dialog
        fields = '__all__'


class DialogAdmin(admin.ModelAdmin):
    form = DialogAdminForm
    list_display = ['hash_entry', 'hash_id', 'callid', 'from_uri', 'from_tag', 'to_uri', 'to_tag', 'caller_cseq', 'callee_cseq', 'caller_route_set', 'callee_route_set', 'caller_contact', 'callee_contact', 'caller_sock', 'callee_sock', 'state', 'start_time', 'timeout', 'sflags', 'iflags', 'toroute_name', 'req_uri', 'xdata']
    readonly_fields = ['hash_entry', 'hash_id', 'callid', 'from_uri', 'from_tag', 'to_uri', 'to_tag', 'caller_cseq', 'callee_cseq', 'caller_route_set', 'callee_route_set', 'caller_contact', 'callee_contact', 'caller_sock', 'callee_sock', 'state', 'start_time', 'timeout', 'sflags', 'iflags', 'toroute_name', 'req_uri', 'xdata']

admin.site.register(Dialog, DialogAdmin)


class DialogVarAdminForm(forms.ModelForm):

    class Meta:
        model = DialogVar
        fields = '__all__'


class DialogVarAdmin(admin.ModelAdmin):
    form = DialogVarAdminForm
    list_display = ['hash_entry', 'hash_id', 'dialog_key', 'dialog_value']
    readonly_fields = ['hash_entry', 'hash_id', 'dialog_key', 'dialog_value']

admin.site.register(DialogVar, DialogVarAdmin)


class AccAdminForm(forms.ModelForm):

    class Meta:
        model = Acc
        fields = '__all__'


class AccAdmin(admin.ModelAdmin):
    form = AccAdminForm
    list_display = ['method', 'from_user', 'from_domain', 'ruri_user', 'ruri_domain', 'callid', 'sip_code', 'sip_reason', 'time', 'time_attr', 'time_exten']
    readonly_fields = ['src_ip', 'method', 'from_user', 'from_domain', 'ruri_user', 'ruri_domain', 'callid', 'sip_code', 'sip_reason', 'time', 'time_attr', 'time_exten', 'cseq', 'ruri_user', 'ruri_domain', 'from_tag', 'to_tag']
    search_fields = ['^callid',]

admin.site.register(Acc, AccAdmin)


class AccCdrAdminForm(forms.ModelForm):

    class Meta:
        model = AccCdr
        fields = '__all__'


class AccCdrAdmin(admin.ModelAdmin):
    form = AccCdrAdminForm
    list_display = ['company_id', 'direction', 'caller', 'callee', 'start_time', 'end_time', 'duration', 'callid']
    readonly_fields = ['company_id', 'direction', 'caller', 'callee', 'start_time', 'end_time', 'duration', 'callid']
    search_fields = ['^caller', '^callee']
    list_filter = ['direction',]

admin.site.register(AccCdr, AccCdrAdmin)


class MissedCallAdminForm(forms.ModelForm):

    class Meta:
        model = MissedCall
        fields = '__all__'


class MissedCallAdmin(admin.ModelAdmin):
    form = MissedCallAdminForm
    list_display = ['method', 'from_tag', 'to_tag', 'callid', 'sip_code', 'sip_reason', 'time']
    readonly_fields = ['src_ip', 'method', 'from_user', 'from_domain', 'ruri_user', 'ruri_domain', 'callid', 'sip_code', 'sip_reason', 'time', 'time_attr', 'time_exten', 'cseq', 'ruri_user', 'ruri_domain', 'from_tag', 'to_tag']
    search_fields = ['^callid',]

admin.site.register(MissedCall, MissedCallAdmin)


class UacRegAdminForm(forms.ModelForm):

    class Meta:
        model = UacReg
        fields = '__all__'


class UacRegAdmin(admin.ModelAdmin):
    form = UacRegAdminForm
    readonly_fields=['flags',]
    list_display = ['l_uuid', 'l_username', 'l_domain', 'r_username', 'r_domain', 'realm', 'auth_username', 'auth_password', 'auth_ha1', 'auth_proxy', 'expires', 'flags', 'reg_delay', 'socket']
    # readonly_fields = ['l_uuid', 'l_username', 'l_domain', 'r_username', 'r_domain', 'realm', 'auth_username', 'auth_password', 'auth_ha1', 'auth_proxy', 'expires', 'flags', 'reg_delay']

admin.site.register(UacReg, UacRegAdmin)


class TrustedAdminForm(forms.ModelForm):

    class Meta:
        model = Trusted
        fields = '__all__'


class TrustedAdmin(admin.ModelAdmin):
    form = TrustedAdminForm
    list_display = ['src_ip', 'proto', 'from_pattern', 'ruri_pattern', 'tag', 'priority']
    # readonly_fields = ['src_ip', 'proto', 'from_pattern', 'ruri_pattern', 'tag', 'priority']

admin.site.register(Trusted, TrustedAdmin)


class VersionAdminForm(forms.ModelForm):

    class Meta:
        model = Version
        fields = '__all__'


class VersionAdmin(admin.ModelAdmin):
    form = VersionAdminForm
    list_display = ['table_name', 'table_version']
    # readonly_fields = ['table_name', 'table_version']

admin.site.register(Version, VersionAdmin)


class LocationAdminForm(forms.ModelForm):

    class Meta:
        model = Location
        fields = '__all__'


class LocationAdmin(admin.ModelAdmin):
    form = LocationAdminForm
    list_display = ['ruid', 'username', 'domain', 'contact', 'received', 'path', 'expires', 'q', 'callid', 'cseq', 'last_modified', 'flags', 'cflags', 'user_agent', 'socket', 'methods', 'instance', 'reg_id', 'server_id', 'connection_id', 'keepalive', 'partition']
    readonly_fields = ['ruid', 'username', 'domain', 'contact', 'received', 'path', 'expires', 'q', 'callid', 'cseq', 'last_modified', 'flags', 'cflags', 'user_agent', 'socket', 'methods', 'instance', 'reg_id', 'server_id', 'connection_id', 'keepalive', 'partition']

admin.site.register(Location, LocationAdmin)


class LocationAttrsAdminForm(forms.ModelForm):

    class Meta:
        model = LocationAttrs
        fields = '__all__'


class LocationAttrsAdmin(admin.ModelAdmin):
    form = LocationAttrsAdminForm
    list_display = ['ruid', 'username', 'domain', 'aname', 'atype', 'avalue', 'last_modified']
    readonly_fields = ['ruid', 'username', 'domain', 'aname', 'atype', 'avalue', 'last_modified']

admin.site.register(LocationAttrs, LocationAttrsAdmin)


class UserBlackListAdminForm(forms.ModelForm):

    class Meta:
        model = UserBlackList
        fields = '__all__'


class UserBlackListAdmin(admin.ModelAdmin):
    form = UserBlackListAdminForm
    list_display = ['username', 'domain', 'prefix', 'whitelist']
    # readonly_fields = ['username', 'domain', 'prefix', 'whitelist']

admin.site.register(UserBlackList, UserBlackListAdmin)


class GlobalBlackListAdminForm(forms.ModelForm):

    class Meta:
        model = GlobalBlackList
        fields = '__all__'


class GlobalBlackListAdmin(admin.ModelAdmin):
    form = GlobalBlackListAdminForm
    list_display = ['prefix', 'whitelist', 'description']
    # readonly_fields = ['prefix', 'whitelist', 'description']

admin.site.register(GlobalBlackList, GlobalBlackListAdmin)


class SpeedDialAdminForm(forms.ModelForm):

    class Meta:
        model = SpeedDial
        fields = '__all__'


class SpeedDialAdmin(admin.ModelAdmin):
    form = SpeedDialAdminForm
    list_display = ['username', 'domain', 'sd_username', 'sd_domain', 'new_uri', 'fname', 'lname', 'description']
    # readonly_fields = ['username', 'domain', 'sd_username', 'sd_domain', 'new_uri', 'fname', 'lname', 'description']

admin.site.register(SpeedDial, SpeedDialAdmin)


class PipeLimitAdminForm(forms.ModelForm):

    class Meta:
        model = PipeLimit
        fields = '__all__'


class PipeLimitAdmin(admin.ModelAdmin):
    form = PipeLimitAdminForm
    list_display = ['pipeid', 'algorithm', 'plimit']
    # readonly_fields = ['pipeid', 'algorithm', 'plimit']

admin.site.register(PipeLimit, PipeLimitAdmin)


class MtreeAdminForm(forms.ModelForm):

    class Meta:
        model = Mtree
        fields = '__all__'


class MtreeAdmin(admin.ModelAdmin):
    form = MtreeAdminForm
    list_display = ['tprefix', 'tvalue']
    readonly_fields = ['tprefix', 'tvalue']

admin.site.register(Mtree, MtreeAdmin)


class MtreesAdminForm(forms.ModelForm):

    class Meta:
        model = Mtrees
        fields = '__all__'


class MtreesAdmin(admin.ModelAdmin):
    form = MtreesAdminForm
    list_display = ['tname', 'tprefix', 'tvalue']
    readonly_fields = ['tname', 'tprefix', 'tvalue']

admin.site.register(Mtrees, MtreesAdmin)


class HtableAdminForm(forms.ModelForm):

    class Meta:
        model = Htable
        fields = '__all__'


class HtableAdmin(admin.ModelAdmin):
    form = HtableAdminForm
    list_display = ['key_name', 'key_type', 'value_type', 'key_value', 'expires']
    readonly_fields = ['key_name', 'key_type', 'value_type', 'key_value', 'expires']

admin.site.register(Htable, HtableAdmin)


class RtpEngineAdminForm(forms.ModelForm):

    class Meta:
        model = RtpEngine
        fields = '__all__'


class RtpEngineAdmin(admin.ModelAdmin):
    form = RtpEngineAdminForm
    list_display = ['setid', 'url', 'weight', 'disabled', 'stamp']
    # readonly_fields = ['setid', 'url', 'weight', 'disabled', 'stamp']

admin.site.register(RtpEngine, RtpEngineAdmin)


class StatisticAdminForm(forms.ModelForm):

    class Meta:
        model = Statistic
        fields = '__all__'


class StatisticAdmin(admin.ModelAdmin):
    form = StatisticAdminForm
    list_display = ['kamailio_id', 'time_stamp', 'random', 'shm_used_size', 'shm_real_used_size', 'shm_max_used_size', 'shm_free_used_size', 'ul_users', 'ul_contacts']
    readonly_fields = ['kamailio_id', 'time_stamp', 'random', 'shm_used_size', 'shm_real_used_size', 'shm_max_used_size', 'shm_free_used_size', 'ul_users', 'ul_contacts']

admin.site.register(Statistic, StatisticAdmin)



# Generated by Django 2.1.5 on 2019-02-26 17:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pyfb_kamailio', '0005_auto_20190225_1803'),
    ]

    operations = [
        migrations.CreateModel(
            name='ToposD',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rectime', models.DateTimeField(db_index=True)),
                ('s_method', models.CharField(default='', max_length=64)),
                ('s_cseq', models.CharField(default='', max_length=64)),
                ('a_callid', models.CharField(db_index=True, default='', max_length=255)),
                ('a_uuid', models.CharField(db_index=True, default='', max_length=255)),
                ('b_uuid', models.CharField(db_index=True, default='', max_length=255)),
                ('a_contact', models.CharField(default='', max_length=128)),
                ('b_contact', models.CharField(default='', max_length=128)),
                ('as_contact', models.CharField(default='', max_length=128)),
                ('bs_contact', models.CharField(default='', max_length=128)),
                ('a_tag', models.CharField(default='', max_length=255)),
                ('b_tag', models.CharField(default='', max_length=255)),
                ('a_rr', models.TextField(blank=True, null=True)),
                ('b_rr', models.TextField(blank=True, null=True)),
                ('s_rr', models.TextField(blank=True, null=True)),
                ('iflags', models.IntegerField(default=0)),
                ('a_uri', models.CharField(default='', max_length=128)),
                ('b_uri', models.CharField(default='', max_length=128)),
                ('r_uri', models.CharField(default='', max_length=128)),
                ('a_srcaddr', models.CharField(default='', max_length=128)),
                ('b_srcaddr', models.CharField(default='', max_length=128)),
                ('a_socket', models.CharField(default='', max_length=128)),
                ('b_socket', models.CharField(default='', max_length=128)),
            ],
            options={
                'db_table': 'topos_d',
                'ordering': ('-pk',),
            },
        ),
        migrations.CreateModel(
            name='ToposT',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('rectime', models.DateTimeField(db_index=True)),
                ('s_method', models.CharField(default='', max_length=64)),
                ('s_cseq', models.CharField(default='', max_length=64)),
                ('a_callid', models.CharField(db_index=True, default='', max_length=255)),
                ('a_uuid', models.CharField(db_index=True, default='', max_length=255)),
                ('b_uuid', models.CharField(default='', max_length=255)),
                ('direction', models.IntegerField(default=0)),
                ('x_via', models.TextField(blank=True, null=True)),
                ('x_vbranch', models.CharField(db_index=True, default='', max_length=255)),
                ('x_rr', models.TextField(blank=True, null=True)),
                ('y_rr', models.TextField(blank=True, null=True)),
                ('s_rr', models.TextField(blank=True, null=True)),
                ('x_uri', models.CharField(default='', max_length=128)),
                ('a_contact', models.CharField(default='', max_length=128)),
                ('b_contact', models.CharField(default='', max_length=128)),
                ('as_contact', models.CharField(default='', max_length=128)),
                ('bs_contact', models.CharField(default='', max_length=128)),
                ('x_tag', models.CharField(default='', max_length=255)),
                ('a_tag', models.CharField(default='', max_length=255)),
                ('b_tag', models.CharField(default='', max_length=255)),
                ('a_srcaddr', models.CharField(default='', max_length=128)),
                ('b_srcaddr', models.CharField(default='', max_length=128)),
                ('a_socket', models.CharField(default='', max_length=128)),
                ('b_socket', models.CharField(default='', max_length=128)),
            ],
            options={
                'db_table': 'topos_t',
                'ordering': ('-pk',),
            },
        ),
    ]
